<?php
/**
* @package phpBB Extension - UCP Sidebar
* @copyright (c) 2018 Sniper_E - https://www.sniper-e.com
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*/

namespace sniper\ucpsidebar\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
* Event listener
*/
class listener implements EventSubscriberInterface
{

	/** @var \phpbb\request\request */
	protected $request;
	
	/* @var \phpbb\template\template */
	protected $template;

	/* @var \phpbb\user */
	protected $user;

	/** @var \phpbb\extension\manager */
	protected $extension_manager;

	/**
	* Constructor
	*
	* @param request_interface	        $request
	* @param template                   $template
	* @param user                       $user
	* @param \phpbb\extension\manager 	$extension_manager
	*/
	public function __construct(\phpbb\request\request $request, \phpbb\template\template $template, \phpbb\user $user, \phpbb\extension\manager $extension_manager)
	{
		$this->request           = $request;
		$this->template          = $template;
		$this->user              = $user;
		$this->extension_manager = $extension_manager;
	}

	static public function getSubscribedEvents()
	{
		return array(
			'core.user_setup'                 => 'load_language_on_setup',
			'core.page_header'                => 'page_header',
			'core.ucp_prefs_view_data'        => 'ucp_prefs_get_data',
			'core.ucp_prefs_view_update_data' => 'ucp_prefs_set_data',
		);
	}

	public function load_language_on_setup($event)
	{
		$lang_set_ext = $event['lang_set_ext'];
		$lang_set_ext[] = array(
			'ext_name' => 'sniper/ucpsidebar',
			'lang_set' => 'ucpsidebar',
		);
		$event['lang_set_ext'] = $lang_set_ext;
	}

	public function page_header($event)
	{
		$this->assign_authors();

		$this->template->assign_vars(array(
			'S_UCP_SIDEBAR'    => !empty($this->user->data['user_ucp_sidebar']) ? true : false,
			'S_SIDEBAR_RIGHT'  => !empty($this->user->data['user_sidebar_right']) ? true : false,
			'S_SIDEBAR_LIGHT'  => !empty($this->user->data['user_sidebar_light']) ? true : false,
		));
	}
	
	protected function assign_authors()
	{
		$md_manager = $this->extension_manager->create_extension_metadata_manager('sniper/ucpsidebar', $this->template);
		$meta = $md_manager->get_metadata();
		$author_homepages = [];
		$hosts = [];

		foreach (array_slice($meta['authors'], 0, 1) as $author)
		{
			$hosts[] = $author['homepage'];
			$author_homepages[] = sprintf ('<a href="%1$s" title="%2$s &middot; %1$s">%3$s </a>', $author['homepage'], $author['sitename'], $author['name']);
		}

		$this->template->assign_vars(array(
			'UCP_SIDEBAR_DISPLAY_NAME'     => $meta['extra']['display-name'],
			'UCP_SIDEBAR_VERSION'          => $meta['version'],
			'UCP_SIDEBAR_AUTHOR_HOMEPAGES' => implode(' &amp; ', $author_homepages),
		));
	}
	
	public function ucp_prefs_get_data($event)
	{
		$event['data'] = array_merge($event['data'], array(
			'ucp_sidebar'    => $this->request->variable('ucp_sidebar', (int) $this->user->data['user_ucp_sidebar']),
			'sidebar_right'  => $this->request->variable('sidebar_right', (int) $this->user->data['user_sidebar_right']),
			'sidebar_light'  => $this->request->variable('sidebar_light', (int) $this->user->data['user_sidebar_light']),
		));

		if (!$event['submit'])
		{
			$this->user->add_lang_ext('sniper/ucpsidebar', 'ucpsidebar_ucp');
			$this->template->assign_vars(array(
				'S_UCP_SIDEBAR'        => $event['data']['ucp_sidebar'],
				'S_UCP_SIDEBAR_RIGHT'  => $event['data']['sidebar_right'],
				'S_UCP_SIDEBAR_LIGHT'  => $event['data']['sidebar_light'],
			));
		}
	}

	public function ucp_prefs_set_data($event)
	{
		$event['sql_ary'] = array_merge($event['sql_ary'], array(
			'user_ucp_sidebar'    => $event['data']['ucp_sidebar'],
			'user_sidebar_right'  => $event['data']['sidebar_right'],
			'user_sidebar_light'  => $event['data']['sidebar_light'],
		));
	}
}
